@@ -14,6 +14,9 @@
 extern "C" {
 #endif /* __cplusplus */ 
 
+#include <nspr.h>
+#include <nss.h>
+
 #include <xmlsec/xmlsec.h>
 #include <xmlsec/keys.h>
 #include <xmlsec/transforms.h>
