@@ -31,6 +31,8 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsNs[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPathNs[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPath2Ns[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPointerNs[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoap11Ns[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoap12Ns[];
 
 
 /*************************************************************************
@@ -75,6 +77,15 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecTypeEncElement[];
  *
  ************************************************************************/
 #ifndef XMLSEC_NO_XKMS
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestResultName[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestStatusName[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestLocateName[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestValidateName[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestCompoundName[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeResult[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatusRequest[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatusResult[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeLocateRequest[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeLocateResult[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidateRequest[];
@@ -94,6 +105,11 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeTimeInstant[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRequestSignatureValue[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeUnverifiedKeyBinding[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidityInterval[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatus[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidReason[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeInvalidReason[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeIndeterminateReason[];
+
 
 XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrService[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNonce[];
@@ -108,10 +124,11 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrRequestId[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNotBefore[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNotOnOrAfter[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrTime[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrStatusValue[];
 
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponsePending[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseRepresent[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseRequestSignatureValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismPending[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismRepresent[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismRequestSignatureValue[];
 
 XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithKeyName[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithKeyValue[];
@@ -133,12 +150,22 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageEncryption[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageSignature[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageExchange[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusValid[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusInvalid[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusIndeterminate[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonIssuerTrust[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonRevocationStatus[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonValidityInterval[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonSignature[];
+
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeSuccess[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeVersionMismatch[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeSender[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeReceiver[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeRepresent[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodePending[];
+
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNoMatch[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeTooManyResponses[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeIncomplete[];
@@ -148,6 +175,21 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNoAuthentication[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeMessageNotSupported[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeUnknownResponseId[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNotSynchronous[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonLang[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonUnsupportedVersion[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonUnableToProcess[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonServiceUnavailable[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonMessageNotSupported[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonMessageInvalid[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapSubcodeValueMessageNotSupported[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapSubcodeValueBadMessage[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrPlain[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrSoap11[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrSoap12[];
+
 #endif /* XMLSEC_NO_XKMS */
 
 /*************************************************************************
@@ -260,6 +302,7 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDSAKeyValue[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSAP[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSAQ[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSAG[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSAJ[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSAX[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSAY[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSASeed[];
@@ -440,6 +483,40 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeXPointer[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameXslt[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefXslt[];
 
+#ifndef XMLSEC_NO_SOAP
+/*************************************************************************
+ *
+ * SOAP 1.1/1.2 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeEnvelope[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeHeader[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeBody[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFault[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFaultCode[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFaultString[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFaultActor[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeFaultDetail[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeCode[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeReason[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeNode[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRole[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDetail[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeSubcode[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeText[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeVersionMismatch[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeMustUnderstand[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeClient[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeServer[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeReceiver[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultCodeSender[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecSoapFaultDataEncodningUnknown[];
+
+
+#endif /* XMLSEC_NO_SOAP */
+
 /*************************************************************************
  *
  * Utility strings
