@@ -4,17 +4,18 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  * 
- * Copyrigth (C) 2002-2003 Aleksey Sanin <aleksey@aleksey.com>
+ * Copyright (C) 2002-2003 Aleksey Sanin <aleksey@aleksey.com>
+ * Copyright (c) 2003 America Online, Inc.  All rights reserved.
  */
 #ifndef XMLSEC_NO_HMAC
 #include "globals.h"
 
 #include <string.h>
 
-#include <nspr/nspr.h>
-#include <nss/nss.h>
-#include <nss/secoid.h>
-#include <nss/pk11func.h>
+#include <nspr.h>
+#include <nss.h>
+#include <secoid.h>
+#include <pk11func.h>
 
 #include <xmlsec/xmlsec.h>
 #include <xmlsec/xmltree.h>
@@ -240,16 +241,13 @@ xmlSecNssHmacSetKey(xmlSecTransformPtr transform, xmlSecKeyPtr key) {
     keyItem.data = xmlSecBufferGetData(buffer);
     keyItem.len  = xmlSecBufferGetSize(buffer); 
 
-    /* this code is taken from PK11_CreateContextByRawKey function;
-     * somehow it just does not work for me */     
     slot = PK11_GetBestSlot(ctx->digestType, NULL);
     if(slot == NULL) {
 	xmlSecError(XMLSEC_ERRORS_HERE, 
 		    xmlSecErrorsSafeString(xmlSecTransformGetName(transform)),
 		    "PK11_GetBestSlot",
 		    XMLSEC_ERRORS_R_CRYPTO_FAILED,
-		    "error=0x%08x",
-		    PR_GetError());
+		    XMLSEC_ERRORS_NO_MESSAGE);
 	return(-1);
     }
 	
@@ -260,8 +258,7 @@ xmlSecNssHmacSetKey(xmlSecTransformPtr transform, xmlSecKeyPtr key) {
 		    xmlSecErrorsSafeString(xmlSecTransformGetName(transform)),
 		    "PK11_ImportSymKey",
 		    XMLSEC_ERRORS_R_CRYPTO_FAILED,
-		    "error=0x%08x",
-		    PR_GetError());
+		    XMLSEC_ERRORS_NO_MESSAGE);
         PK11_FreeSlot(slot);
 	return(-1);
     }
@@ -272,8 +269,7 @@ xmlSecNssHmacSetKey(xmlSecTransformPtr transform, xmlSecKeyPtr key) {
 		    xmlSecErrorsSafeString(xmlSecTransformGetName(transform)),
 		    "PK11_CreateContextBySymKey",
 		    XMLSEC_ERRORS_R_CRYPTO_FAILED,
-		    "error=0x%08x",
-		    PR_GetError());
+		    XMLSEC_ERRORS_NO_MESSAGE);
 	PK11_FreeSymKey(symKey);
         PK11_FreeSlot(slot);
 	return(-1);
@@ -389,8 +385,7 @@ xmlSecNssHmacExecute(xmlSecTransformPtr transform, int last, xmlSecTransformCtxP
 			    xmlSecErrorsSafeString(xmlSecTransformGetName(transform)),
 			    "PK11_DigestOp",
 			    XMLSEC_ERRORS_R_CRYPTO_FAILED,
-			    "error=0x%08x",
-			    PR_GetError());
+			    XMLSEC_ERRORS_NO_MESSAGE);
 		return(-1);
 	    }
 	    
