@@ -26,6 +26,8 @@ const xmlChar xmlSecXkmsNs[] 			= "http://www.w3.org/2002/03/xkms#";
 const xmlChar xmlSecXPathNs[] 			= "http://www.w3.org/TR/1999/REC-xpath-19991116";
 const xmlChar xmlSecXPath2Ns[] 			= "http://www.w3.org/2002/06/xmldsig-filter2";
 const xmlChar xmlSecXPointerNs[]		= "http://www.w3.org/2001/04/xmldsig-more/xptr";
+const xmlChar xmlSecSoap11Ns[]			= "http://schemas.xmlsoap.org/soap/envelope/";
+const xmlChar xmlSecSoap12Ns[]			= "http://www.w3.org/2002/06/soap-envelope";
 
 /*************************************************************************
  *
@@ -70,6 +72,15 @@ const xmlChar xmlSecTypeEncElement[]		= "http://www.w3.org/2001/04/xmlenc#Elemen
  *
  ************************************************************************/
 #ifndef XMLSEC_NO_XKMS
+const xmlChar xmlSecXkmsServerRequestResultName[]	= "result-response";
+const xmlChar xmlSecXkmsServerRequestStatusName[]	= "status-request";
+const xmlChar xmlSecXkmsServerRequestLocateName[]	= "locate-request";
+const xmlChar xmlSecXkmsServerRequestValidateName[]	= "validate-request";
+const xmlChar xmlSecXkmsServerRequestCompoundName[]	= "compound-request";
+
+const xmlChar xmlSecNodeResult[]		= "Result";
+const xmlChar xmlSecNodeStatusRequest[]		= "StatusRequest";
+const xmlChar xmlSecNodeStatusResult[]		= "StatusResult";
 const xmlChar xmlSecNodeLocateRequest[]		= "LocateRequest";
 const xmlChar xmlSecNodeLocateResult[]		= "LocateResult";
 const xmlChar xmlSecNodeValidateRequest[]	= "ValidateRequest";
@@ -89,6 +100,10 @@ const xmlChar xmlSecNodeTimeInstant[]		= "TimeInstant";
 const xmlChar xmlSecNodeRequestSignatureValue[]	= "RequestSignatureValue";
 const xmlChar xmlSecNodeUnverifiedKeyBinding[]	= "UnverifiedKeyBinding";
 const xmlChar xmlSecNodeValidityInterval[]	= "ValidityInterval";
+const xmlChar xmlSecNodeStatus[]                = "Status";
+const xmlChar xmlSecNodeValidReason[]           = "ValidReason";
+const xmlChar xmlSecNodeInvalidReason[]         = "InvalidReason";
+const xmlChar xmlSecNodeIndeterminateReason[]   = "IndeterminateReason";
 
 const xmlChar xmlSecAttrService[]		= "Service";
 const xmlChar xmlSecAttrNonce[]			= "Nonce";
@@ -103,10 +118,11 @@ const xmlChar xmlSecAttrRequestId[]		= "RequestId";
 const xmlChar xmlSecAttrNotBefore[]		= "NotBefore";
 const xmlChar xmlSecAttrNotOnOrAfter[]		= "NotOnOrAfter";
 const xmlChar xmlSecAttrTime[]			= "Time";
+const xmlChar xmlSecAttrStatusValue[]           = "StatusValue";
 
-const xmlChar xmlSecResponsePending[]		= "Pending";
-const xmlChar xmlSecResponseRepresent[]		= "Represent";
-const xmlChar xmlSecResponseRequestSignatureValue[] = "RequestSignatureValue";
+const xmlChar xmlSecResponseMechanismPending[]	= "Pending";
+const xmlChar xmlSecResponseMechanismRepresent[]= "Represent";
+const xmlChar xmlSecResponseMechanismRequestSignatureValue[] = "RequestSignatureValue";
 
 const xmlChar xmlSecRespondWithKeyName[]	= "KeyName";
 const xmlChar xmlSecRespondWithKeyValue[]	= "KeyValue";
@@ -128,21 +144,46 @@ const xmlChar xmlSecKeyUsageEncryption[]	= "Encryption";
 const xmlChar xmlSecKeyUsageSignature[]		= "Signature";
 const xmlChar xmlSecKeyUsageExchange[]		= "Exchange";
 
-const xmlChar xmlSecResultMajorCodeSuccess[]	= "Success";
-const xmlChar xmlSecResultMajorCodeVersionMismatch[]= "VersionMismatch";
-const xmlChar xmlSecResultMajorCodeSender[]	= "Sender";
-const xmlChar xmlSecResultMajorCodeReceiver[]	= "Receiver";
-const xmlChar xmlSecResultMajorCodeRepresent[]	= "Represent";
-const xmlChar xmlSecResultMajorCodePending[]	= "Pending";
-const xmlChar xmlSecResultMinorCodeNoMatch[]	= "NoMatch";
+const xmlChar xmlSecKeyBindingStatusValid[]	        = "Valid";
+const xmlChar xmlSecKeyBindingStatusInvalid[]	        = "Invalid";
+const xmlChar xmlSecKeyBindingStatusIndeterminate[]	= "Indeterminate";
+
+const xmlChar xmlSecKeyBindingReasonIssuerTrust[]       = "IssuerTrust";
+const xmlChar xmlSecKeyBindingReasonRevocationStatus[]  = "RevocationStatus";
+const xmlChar xmlSecKeyBindingReasonValidityInterval[]  = "ValidityInterval";
+const xmlChar xmlSecKeyBindingReasonSignature[]         = "Signature";
+
+const xmlChar xmlSecResultMajorCodeSuccess[]		= "Success";
+const xmlChar xmlSecResultMajorCodeVersionMismatch[]	= "VersionMismatch";
+const xmlChar xmlSecResultMajorCodeSender[]		= "Sender";
+const xmlChar xmlSecResultMajorCodeReceiver[]		= "Receiver";
+const xmlChar xmlSecResultMajorCodeRepresent[]		= "Represent";
+const xmlChar xmlSecResultMajorCodePending[]		= "Pending";
+
+const xmlChar xmlSecResultMinorCodeNoMatch[]		= "NoMatch";
 const xmlChar xmlSecResultMinorCodeTooManyResponses[]	= "TooManyResponses";
-const xmlChar xmlSecResultMinorCodeIncomplete[]	= "Incomplete";
-const xmlChar xmlSecResultMinorCodeFailure[]	= "Failure";
-const xmlChar xmlSecResultMinorCodeRefused[]	= "Refused";
+const xmlChar xmlSecResultMinorCodeIncomplete[]		= "Incomplete";
+const xmlChar xmlSecResultMinorCodeFailure[]		= "Failure";
+const xmlChar xmlSecResultMinorCodeRefused[]		= "Refused";
 const xmlChar xmlSecResultMinorCodeNoAuthentication[]	= "NoAuthentication";
 const xmlChar xmlSecResultMinorCodeMessageNotSupported[]= "MessageNotSupported";
 const xmlChar xmlSecResultMinorCodeUnknownResponseId[]	= "UnknownResponseId";
 const xmlChar xmlSecResultMinorCodeNotSynchronous[]	= "NotSynchronous";
+
+const xmlChar xmlSecXkmsSoapSubcodeValueMessageNotSupported[] = "MessageNotSupported";
+const xmlChar xmlSecXkmsSoapSubcodeValueBadMessage[]	= "BadMessage";
+
+const xmlChar xmlSecXkmsSoapFaultReasonLang[] 		    = "en";
+const xmlChar xmlSecXkmsSoapFaultReasonUnsupportedVersion[] = "Unsupported SOAP version";
+const xmlChar xmlSecXkmsSoapFaultReasonUnableToProcess[]    = "Unable to process %s";
+const xmlChar xmlSecXkmsSoapFaultReasonServiceUnavailable[] = "Service temporarily unable";
+const xmlChar xmlSecXkmsSoapFaultReasonMessageNotSupported[]= "%s message not supported";
+const xmlChar xmlSecXkmsSoapFaultReasonMessageInvalid[]     = "%s message invalid";
+
+const xmlChar xmlSecXkmsFormatStrPlain[]                = "plain";
+const xmlChar xmlSecXkmsFormatStrSoap11[]               = "soap-1.1";
+const xmlChar xmlSecXkmsFormatStrSoap12[]               = "soap-1.2";
+
 #endif /* XMLSEC_NO_XKMS */
 
 /*************************************************************************
@@ -253,6 +294,7 @@ const xmlChar xmlSecHrefDSAKeyValue[]		= "http://www.w3.org/2000/09/xmldsig#DSAK
 const xmlChar xmlSecNodeDSAP[]			= "P";
 const xmlChar xmlSecNodeDSAQ[]			= "Q";
 const xmlChar xmlSecNodeDSAG[]			= "G";
+const xmlChar xmlSecNodeDSAJ[]			= "J";
 const xmlChar xmlSecNodeDSAX[]			= "X";
 const xmlChar xmlSecNodeDSAY[]			= "Y";
 const xmlChar xmlSecNodeDSASeed[]		= "Seed";
@@ -432,6 +474,41 @@ const xmlChar xmlSecNodeXPointer[]		= "XPointer";
 const xmlChar xmlSecNameXslt[]			= "xslt";
 const xmlChar xmlSecHrefXslt[]			= "http://www.w3.org/TR/1999/REC-xslt-19991116";
 
+#ifndef XMLSEC_NO_SOAP
+/*************************************************************************
+ *
+ * SOAP 1.1/1.2 strings
+ *
+ ************************************************************************/
+const xmlChar xmlSecNodeEnvelope[]		= "Envelope";
+const xmlChar xmlSecNodeHeader[]		= "Header";
+const xmlChar xmlSecNodeBody[]		        = "Body";
+const xmlChar xmlSecNodeFault[]		        = "Fault";
+const xmlChar xmlSecNodeFaultCode[]		= "faultcode";
+const xmlChar xmlSecNodeFaultString[]	        = "faultstring";
+const xmlChar xmlSecNodeFaultActor[]	        = "faultactor";
+const xmlChar xmlSecNodeFaultDetail[]	        = "detail";
+const xmlChar xmlSecNodeCode[]			= "Code";
+const xmlChar xmlSecNodeReason[]		= "Reason";
+const xmlChar xmlSecNodeNode[]			= "Node";
+const xmlChar xmlSecNodeRole[]			= "Role";
+const xmlChar xmlSecNodeDetail[]		= "Detail";
+const xmlChar xmlSecNodeValue[]			= "Value";
+const xmlChar xmlSecNodeSubcode[]		= "Subcode";
+const xmlChar xmlSecNodeText[]			= "Text";
+
+
+const xmlChar xmlSecSoapFaultCodeVersionMismatch[] 	= "VersionMismatch";
+const xmlChar xmlSecSoapFaultCodeMustUnderstand[]	= "MustUnderstand";
+const xmlChar xmlSecSoapFaultCodeClient[]		= "Client";
+const xmlChar xmlSecSoapFaultCodeServer[]		= "Server";
+const xmlChar xmlSecSoapFaultCodeReceiver[]		= "Receiver";
+const xmlChar xmlSecSoapFaultCodeSender[]		= "Sender";
+const xmlChar xmlSecSoapFaultDataEncodningUnknown[]	= "DataEncodingUnknown";
+
+
+#endif /* XMLSEC_NO_SOAP */
+
 /*************************************************************************
  *
  * Utility strings
